<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Nivell %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Cap caràtula</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Introdueixi la nova extensió:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Crear una nova extensió</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Esborrar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>Directori que conté els vídeos</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>Aquest directori ha d&apos;existir i MythVideo ha de tenir accès de lectura en el directori.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>Nivell d&apos;accès parental inicial</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 - Superior</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - Inferior</translation>
    </message>
    <message>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <source>3</source>
        <translation></translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation>Aquest és el &apos;nivell&apos; en el que MythVideo s&apos;inicia. Qualsevol video amb un nivell inferior serà visualitzat a la llista per omisió. El PIN de ontrol d&apos;accès té que ser activat per canviar el aquest nivell per omisió.</translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>PIN de control d&apos;accès</translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier. If you don&apos;t want to be bothered by PC dialogs, please set it to be blank.</source>
        <translation type="obsolete">Aquest PIN es fa servir per al control d&apos;accès parental. So vol activar aquesta funció utilitzi números, li resultarà més senzill. Si no vol ser molestat amb diàlegs sol·licitant el PIN, no hi assigni cap valor.</translation>
    </message>
    <message>
        <source>Aggresive Parental Control</source>
        <translation type="obsolete">Control d&apos;accès estricte</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation>Si està actiu, no podrà retornar a aquesta pantalla i reinicialitzar el PIN de control d&apos;accès sense avans entrar el PIN actual. És un avís.</translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>Visualitza fitxers amb extensió desconeguda</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation>Si està actiu, tots els fitxers del directoris de MythVideo es visualitzen a no ser que la seva extensió estipuli explícitament d&apos;ignorar-los.</translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation>La llista de vídeos explora fitxers</translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Si està actiu, la pantalla que llista els vídeos visualitzará tots els arxius del directori de MythVideo encara que no hagin estat escanejats.</translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined.</source>
        <translation type="obsolete">Aquesta és la comanda emprada per a les extensions no definides.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Opcions Generals</translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>Opcions del reproductor</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation>Pin d&apos;accés:</translation>
    </message>
    <message>
        <source>Searching for video files</source>
        <translation>Cercant arxius de vídeo</translation>
    </message>
    <message>
        <source>Updating video database</source>
        <translation>Actualitzant base de dades de vídeos</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Cap caràtula</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>NR</source>
        <translation></translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation>No classificat</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Reproductor per omisió</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Listings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Director:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Any:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Classificació:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>Nivell d&apos;accés:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>Llistable:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Duració:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Resum:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Nom de l&apos;arxiu:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Caràtula:</translation>
    </message>
    <message>
        <source>0-9: Edit</source>
        <translation type="obsolete">0-9: Editar</translation>
    </message>
    <message>
        <source>Menu/Info: Manual IMDB</source>
        <translation type="obsolete">Menu/Info: IMDB Manual</translation>
    </message>
    <message>
        <source>Enter/OK: Auto IMDB</source>
        <translation type="obsolete">Enter/OK: IMDB automatisch</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>obtenint informació...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ cercant ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>IntroduÏr IMDB #</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>carregant...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>No trovo vídeos</translation>
    </message>
    <message>
        <source>Use the left and right arrows</source>
        <translation type="obsolete">Cursor esq/dreta per navegar</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Director</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Arxiu:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Comanda:</translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>Associació d&apos;arxius a MythVideo</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Extensió:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Comanda:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Reproductor:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Ignorar:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Editar Informació del vídeo</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>Nivell d&apos;Accès:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>Arxiu a reproduir després:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>Incloure al llistar:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Imatge de caràtula:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Comanda d&apos;execució específica:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/directori/per/la/imatge.jpg</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PL </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Country :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">PIN de control d&apos;accès:</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 de %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>Sense vídeos</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation>Sense classificació disponible.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuts</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Desconegut</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished">Fet</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>Sorry there were no matches for the title</source>
        <translation type="obsolete">Ho sento, no s&apos;han trovat coincidències per a aquest títol</translation>
    </message>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation type="unfinished">Especificar manualment entrada IMDB#</translation>
    </message>
    <message>
        <source>Reset Entry</source>
        <translation type="obsolete">Reiniciar entrada</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuts</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <source>No</source>
        <translation></translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Cap caràtula</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Cap</translation>
    </message>
    <message>
        <source>NR</source>
        <translation></translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation type="unfinished">Sense classificació disponible.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation>PIN d&apos;accés:</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>No s&apos;han trovat arxius</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
